The Model Hamiltonian
=====================

.. automodule:: ggce.model
   :members:
   :undoc-members:
   :show-inheritance:

The Matrix Generation Engine
============================

Terms
-----

.. automodule:: ggce.engine.terms
   :members:
   :undoc-members:
   :show-inheritance:

Equations
---------

.. automodule:: ggce.engine.equations
   :members:
   :undoc-members:
   :show-inheritance:

System
------

.. automodule:: ggce.engine.system
   :members:
   :undoc-members:
   :show-inheritance:

Solvers
=======
.. Need to change this to just executors/solvers to doc everything
.. automodule:: ggce.executors.solvers
   :members:
   :undoc-members:
   :show-inheritance:
